@@ -1,3 +1,3 @@
 # Setting global variables to avoid R CMD check notices
 utils::globalVariables(c('average', 'trend', 'year','Year', 'J-D', 'gmsl', 'method', 'month',
-                         'age_ice', 'co2', 'temp', 'value', 'size', 'measure','RevisedMajorHurricanes', 'RevisedACE'))
+                         'age_ice', 'co2', 'temp', 'value', 'size', 'measure','RevisedMajorHurricanes', 'RevisedACE', 'iso_code'))
